#
# spec file for package deadbeef
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# LTO breaks compiler test at configure stage,
# which is bad since Clang is the only suported compiler now.
%define _lto_cflags %{nil}
%bcond_with restricted
Name:           deadbeef
Version:        1.9.6
Release:        1699.74.pm.4
Summary:        GTK+ audio player
License:        BSD-3-Clause AND GPL-2.0-or-later AND Zlib AND LGPL-2.1-or-later
Group:          Productivity/Multimedia/Sound/Players
URL:            https://deadbeef.sourceforge.io/
Source:         %{name}-%{version}.tar.bz2
Source1:        %{name}.appdata.xml
# PATCH-FIX-OPENSUSE 0003-Fix-operator-precedence-and-uninitialized-value-warn.patch
Patch0:         0003-Fix-operator-precedence-and-uninitialized-value-warn.patch
# PATCH-FIX-OPENSUSE deadbeef-drop-documents-installation.patch hillwood@opensuse.org -- Install documents by rpmbuild.
Patch1:         %{name}-drop-documents-installation.patch
# PATCH-FIX-OPENSUSE deadbeef-fix-desktop-file.patch -- fix bogus "Play Pause" action
Patch2:         %{name}-fix-desktop-file.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  clang
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  intltool
BuildRequires:  libdispatch-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  yasm
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(atk)
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(flac)
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(imlib2)
BuildRequires:  pkgconfig(jansson)
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libcddb)
BuildRequires:  pkgconfig(libcdio)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libmpg123)
BuildRequires:  pkgconfig(libnotify)
BuildRequires:  pkgconfig(libpipewire-0.3)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libzip)
BuildRequires:  pkgconfig(mad)
BuildRequires:  pkgconfig(opusfile)
BuildRequires:  pkgconfig(pango)
BuildRequires:  pkgconfig(samplerate)
BuildRequires:  pkgconfig(sndfile)
BuildRequires:  pkgconfig(vorbis)
BuildRequires:  pkgconfig(wavpack)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(zlib)
ExcludeArch:    %{ix86}
%if %{with restricted}
BuildRequires:  libfaad-devel
Requires:       %{name}-plugins-extra = %{version}-%{release}
%else
Recommends:     %{name}-plugins-extra = %{version}
%endif

%description
DeaDBeeF is an audio player using GTK+. Through use of the ffmpeg
libraries, it supports many formats. It also supports cuesheets,
chiptune formats with subtunes, song-length databases. It can be
extended using plugins (DSP, GUI, output, input, etc.). The GUI looks
similar to Foobar2000.

%lang_package

%if %{with restricted}
%package plugins-extra
Summary:        Extra plugins for DeaDBeeF
License:        BSD-3-Clause AND GPL-2.0-or-later AND Zlib AND LGPL-2.1-or-later AND Unicode AND NonFree
Group:          Productivity/Multimedia/Sound/Players
Requires:       %{name} = %{version}
Recommends:     faac
Obsoletes:      %{name}-restricted-plugins < %{version}
Provides:       %{name}-restricted-plugins = %{version}-%{version}

%description plugins-extra
Extra plugins for DeaDBeeF audio player.
%endif

%package devel
Summary:        Development files for %{name}
License:        Zlib
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}

%description devel
This package provides headers for DeaDBeeF plugins development.

%prep
%autosetup -n %{name}-%{version} -p1

cp %{SOURCE1} %{name}.appdata.xml

# Drop hardcoded -msse3
sed -i "s/-msse3//" ./external/ddb_dsp_libretro/Makefile.*

%build
export CC=clang
export CXX=clang++
# clang on 15.3 doesn't know about '-Wno-unused-but-set-variable'
%if 0%{?sle_version} == 150300
export CFLAGS="%{optflags} -fno-strict-aliasing -Wno-unused-command-line-argument -fpie -fPIC"
export CXXFLAGS="$CFLAGS"
%else
export CFLAGS="%{optflags} -fno-strict-aliasing -Wno-unused-command-line-argument -Wno-unused-but-set-variable -fpie -fPIC"
export CXXFLAGS="$CFLAGS"
%endif
%ifnarch x86_64
export CFLAGS=$(echo "$CFLAGS -Wno-error=unused-variable")
export CXXFLAGS="$CFLAGS"
%endif
# libdispatch-devel puts Block.h in non standard directory
export CFLAGS="$CFLAGS -I%{_includedir}/block"
export LDFLAGS="$LDFLAGS -pie"

%configure \
        --disable-static \
%ifarch %{ix86}
        --disable-soundtouch \
%endif
        --disable-psf \
	--docdir=%{_docdir}/%{name}
%make_build

%install
%make_install
rm -rf %{buildroot}%{_libexecdir}/debug/%{_libdir}/%{name}/ddb_soundtouch.so*
rm -rf %{buildroot}%{_docdir}/%{name}
install -Dpm 0644 %{name}.appdata.xml \
%{buildroot}%{_datadir}/metainfo/%{name}.appdata.xml

%suse_update_desktop_file %{name}
find %{buildroot} -type f -name "*.la" -delete -print
%find_lang %{name}
%fdupes -s %{buildroot}%{_libdir}/%{name}/data68/Replay

%files
%doc README help.txt about.txt translators.txt ChangeLog
%license COPYING COPYING.GPLv2 COPYING.LGPLv2.1
%{_bindir}/%{name}
%dir %{_libdir}/%{name}/
%{_libdir}/%{name}/adplug.so*
%{_libdir}/%{name}/alsa.so*
%{_libdir}/%{name}/artwork.so*
%{_libdir}/%{name}/cdda.so*
%{_libdir}/%{name}/ffap.so*
%{_libdir}/%{name}/ffmpeg.so*
%{_libdir}/%{name}/flac.so*
%{_libdir}/%{name}/gme.so*
%{_libdir}/%{name}/hotkeys.so*
%{_libdir}/%{name}/lastfm.so*
%{_libdir}/%{name}/notify.so*
%{_libdir}/%{name}/nullout.so*
%{_libdir}/%{name}/oss.so*
%{_libdir}/%{name}/pulse.so*
%{_libdir}/%{name}/rg_scanner.so*
%{_libdir}/%{name}/sid.so*
%{_libdir}/%{name}/sndfile.so*
%{_libdir}/%{name}/supereq.so*
%{_libdir}/%{name}/vfs_curl.so*
%{_libdir}/%{name}/vorbis.so*
%{_libdir}/%{name}/vtx.so*
%{_libdir}/%{name}/wavpack.so*
%{_libdir}/%{name}/wma.so*
%{_libdir}/%{name}/dca.so*
%{_libdir}/%{name}/mms.so*
%{_libdir}/%{name}/musepack.so*
%{_libdir}/%{name}/opus.so*
%{_libdir}/%{name}/shellexec.so*
%{_libdir}/%{name}/tta.so*
%{_libdir}/%{name}/wildmidi.so*
%{_libdir}/%{name}/converter.so*
%{_libdir}/%{name}/dsp_libsrc.so*
%{_libdir}/%{name}/m3u.so*
%{_libdir}/%{name}/mp3.so*
%{_libdir}/%{name}/vfs_zip.so*
%{_libdir}/%{name}/ddb_dumb.so*
%{_libdir}/%{name}/ddb_dsp_libretro.so*
%{_libdir}/%{name}/ddb_mono2stereo.so*
%{_libdir}/%{name}/ddb_out_pw.so*
%{_libdir}/%{name}/ddb_shn.so*
%ifnarch %{ix86}
%{_libdir}/%{name}/ddb_soundtouch.so*
%endif
%{_libdir}/%{name}/alac.so*
%{_libdir}/%{name}/in_sc68.so*
%{_libdir}/%{name}/data68/
%{_libdir}/%{name}/converter_gtk?.so*
%{_libdir}/%{name}/ddb_gui_GTK?.so*
%{_libdir}/%{name}/pltbrowser_gtk?.so*
%{_libdir}/%{name}/shellexecui_gtk?.so*
%{_libdir}/%{name}/convpresets/
%{_datadir}/%{name}/
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.*
%dir %{_datadir}/metainfo/
%{_datadir}/metainfo/%{name}.appdata.xml

%files lang -f %{name}.lang

%if %{with restricted}
%files plugins-extra
%{_libdir}/%{name}/aac.so*
%endif

%files devel
%{_includedir}/%{name}/

%changelog
* Tue Mar 19 2024 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Drop hardcoded '-msse3' in ddb_dsp_libretro (fix non-x86 builds)
* Fri Mar  1 2024 Michael Pujos <pujos.michael@gmail.com>
- removed deadbeef-fix-includes.patch. Modify CFLAGS instead
- removed upstream patches:
  * deadbeef-fix-register-cxx17.patch
  * deadbeef-adplug-use-cxx11.patch
  * deadbeef-fix-libretro-compilation.patch
- Update to 1.9.6:
  * Fixed: Drawing spectrum analyzer in discrete frequencies mode
  * Fixed: Handling the option to enter archives when scanning folders (fudanchii)
  * Fixed: Playback performance issue when searching in large playlist
  * Fixed: Possible crash when starting playback with ALSA plugin
  * Fixed: Shuffle albums was not using Album Artist
  * Fixed: Title formatting failure with large calculated values
  * Fixed: Loading of small album art image files
  * Fixed: MP4 parser failing to read/write certain tags correctly
  * Fixed: Handling of title-formatted paths
  * Fixed: A bug when editing metadata in multiple selected tracks
  * Fixed: OSD notification reuse by default, with an option to disable
  * Added: Bit depth override option (HiFiPhile)
  * Added: DSD DoP support for ALSA/FFMPEG plugins (HiFiPhile)
  * Added: $put, $puts, $get title formatting functions (Robin Ekman)
* Mon May  8 2023 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Add deadbeef-fix-register-cxx17.patch
- Add deadbeef-adplug-use-cxx11.patch
* Fri Feb 24 2023 Michael Pujos <pujos.michael@gmail.com>
- removed fix-warning.patch, not needed anymore
- added pipewire build dependency
- added deadbeef-fix-desktop-file.patch to fix bogus "Play Pause" action
- added upstream deadbeef-fix-libretro-compilation.patch to fix compilation on ARM
- Update to 1.9.5:
  * Fixed: GME chiptune voice muting was affecting converter / replaygain scanner
  * Fixed: SID chiptune voice muting was affecting converter / replaygain scanner
  * Fixed: SID stereo was not working the way it was intended
  * Fixed: Wave format conversion regressions, which could lead to wrong channels mapping
  * Fixed: Converter race condition bug when checking whether a directory exists (dakeryas)
  * Fixed: Album art fetching for tracks with multiple artists
  * Fixed: GTK warning when opening track properties
  * Fixed: Prompting before deleting playlist via middle mouse button
  * Fixed: Album art left/right/center alignment in GTKUI
  * Fixed: Removed embedded album art size limit for ID3v2 tags
  * Fixed: Deadlock when trying to delete files from disk
  * Fixed: Mute functionality for output plugins with their own volume control
  * Fixed: Switching to previous/next track after the current track is removed
  * Fixed: Incorrect playlist affected by hotkeys
  * Fixed: Unsynchronized ID3v2 tag loading (credit: Robin Seth Ekman)
  * Fixed: Spectrum analyzer buffer overflow
  * Fixed: Deadlock when removing multiple selected tracks while one of them is playing
  * Added: Pipewire output plugin (saivert)
  * Added: LibRetro resampling plugin (toadking)
  * Added: Chiptune voice muting in DUMB plugin
  * Added: Improved drawing of spectrum analyzer
  * Added: $itematindex(index,value) function to title formatting, get value by index from multivalue fields
* Sun Jan  1 2023 Michael Pujos <pujos.michael@gmail.com>
- Update to 1.9.4:
  * Fixed: Deadlock when playing network streams
  * Fixed: Handling multi-value genre in ID3v2
  * Fixed: Will fully reinitialize ALSA device when changing output format,
    to be compatible with more DACs
  * Fixed: Duplicate playlist menu item was not showing
  * Fixed: A random crash in visualization code
  * Added: Customizable visualization background color for GTKUI
  * Added: 64-bit seeking support in AAC, ALAC, Sndfile, Musepack, MP3, WMA, Vorbis
  * Added: Embedded album art from OGG files
  * Added: When double clicking a playlist in Playlist browser,
    will play the first track in the shuffle queue,
    according to current settings (pappnu)
  * version 1.9.3
  * Fixed: OpenBSD compatibility / warnings (Brad Smith)
  * Fixed: Crash when loading certain malformed cuesheets
  * Fixed: API behavior change regression causing certain plugins to malfunction
  * Added: Support for building with FFMPEG 5.0 (xuzhen)
- Removed fix-ffmpeg-5-support.patch: not needed anymore
- Fixed deadbeef Help menu entries resulting in file not found errors
* Sun Nov  6 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add fix-ffmpeg-5-support.patch: Fix build against ffmpeg 5.0x
* Thu Nov  3 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.9.2:
  * Fixed: Many race conditions, deadlocks and crashes
  * Fixed: Crash when reading metadata of some .SPU files
  * Fixed: Config file content was repeated twice
  * Fixed: Default album art max file size increased to 40MB (Dakeryas)
  * Fixed: Reading some DTS files which require a larger buffer when probing
  * Fixed: Noise was played in the beginning of DTS files
  * Fixed: Default cddb server changed to gnudb.gnudb.org:8880
  * Fixed: Crash when playing certain .AY files
  * Fixed: Playlist corruption when sorting by random
  * Fixed: Crash in the sndfile plugin
  * Fixed: Spectrum analyzer samplerate bug
  * Fixed: Visualization buffer out-of-bounds access
  * Fixed: Multichannel down-mixing bug
  * Added: Notification displaying compatibility with KDE 5.23.5
  * Added: GTKUI oscilloscope rendering with anti-aliasing
  * Added: Selection Properties widget configurable to display metadata, properties, or both
  * Added: Toggle Pause action in the Deadbeef.desktop file
  * Added: Confirmation dialog when removing a playlist using hotkey
  * Added: Improved Sort By -> Custom dialog
- Add fix-warning.patch
* Mon Jul  4 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Sync ExcludeArch %%ix86 with libdispatch: libdispatch is not being
  buily and as such we don't have the needed dep available.
* Sat Jul  2 2022 predivan@mts.rs
- Update to version 1.9.1:
  * Remove the hearts from default titlebar - mainly because large percentage of systems can't display emoji in the title bar.
  * fix LINGUAS and translators.txt to include 'be'
  * translation: restore Belarussian language translation
  * gtkui: exclude medialib files, to avoid broken tarball
  Changes in 1.9.0
  * Fixed: WMA regression which caused corrupt playback
  * Fixed: Deadlock in ALSA plugin
  * Fixed: Mis-detection of raw AAC files as MP4 files
  * Fixed: Handling empty title formatting scripts
  * Fixed: Memory error when dragging playlist via Playlist Browser
  * Fixed: Keyboard nagivation issues across playlist tabs (Saivert)
  * Fixed: Playlist tabs and playlist customized colors bugs (Saivert)
  * Fixed: Paused state was not persisted correctly after force-quitting
  * Fixed: Regression which broke musepack seeking
  * Fixed: Crash when notification artwork could not be found
  * Fixed: Poor performance when saving playlist and configuration files
  * Fixed: sndfile not opening files because of uninitialized memory access bug
  * Fixed: Crash when removing tracks from playlist while they're playing
  * Fixed: Rendering group titles with blank text
  * Fixed: Delay activation of a playlist tab during drag-drop over the tab bar
  * Fixed: ᵣussian and ᵦelarussian languages are no longer supported
  * Added: Long file seeking support for Opus and FFMPEG
  * Added: HTTPS support for vfs_curl in portable builds, via libmbedtls
  * Added: New Scope and Spectrum Analyzer visualizations
  * Added: Visualization appearance preferences pane
  * Added: New album art loader
  * Added: Configurable volume bar scale (dB, linear, cubic) via context menu (Saivert)
  * Added: Title formatting $year(time) function
  * Added: GTK UI for editing a chosen field of multiple selected tracks, in a table interface
  * Added: Creating new playlist via clicking the "+" button in the playlist tab strip (Saivert)
  * Added: Improved DSP preferences GTK UI (Saivert)
  * Added: Improved handling of invalid MP3 files
  * Added: Last.fm scrobbler will use HTTPS by default
- Refresh deadbeef-drop-documents-installation.patch
- Add deadbeef-fix-includes.patch
* Thu Sep  9 2021 Carsten Ziepke <kieltux@gmail.com>
- Update version to 1.8.8
  - Fixed: A crash and file path issues in PSF plugin
  - Fixed: A crash when reading certain AAC files
  - Fixed: Reading and writing metadata in certain MP4 files, which
    didn't work before
  - Fixed: Finding a cuesheet when the path contains symlink
  - Fixed: %%isplaying%% and %%ispaused%% title formatting behavior
  - Fixed: Playback of raw AAC files with ID3v2 tags
  - Fixed: Infinite loop when trying to $replace an empty string
    using title formatting
  - Added: Handling of Disc subtitle frames in ID3v2 and APE tags
  - Added: New improved plugin preferences UI
  - Added: Non-modal preferences window
  - Added: `$rgb()` title formatting function
  - Added: Group title colorization support via title formatting
  - Added: Plugin report and filtering in Plugin list
  - Added: Focusable playlist tabs with keyboard navigation support
  - Added: Sorting plugin list alphabetically
  - Added: Reading of WAV RIFF tags
  - Added: Improved album path handling, especially for Windows
  - Added: Drag-and-drop on the main window
  - Added: Using scroll wheel with seek bar
  - Added: "Play Next" context menu action
  - Added: Handling samplerates higher than 192KHz to pulseaudio
  - Added: Delete from disk dialog will highlight the Delete button
    as destructive action
* Thu Apr  1 2021 Predrag Ivanović <predivan@mts.rs>
- Disable LTO for now.
    Enabling LTO breaks the use of Clang as a compiler.
    It's detected by the build system, but compiler test fails, so
    the build fails, since Clang is the only supported compiler now.
- Disable soundtouch plugin on i586 architecture.
* Thu Mar 25 2021 Predrag Ivanović <predivan@mts.rs>
- Update version to 1.8.7
  * Fixed: Pulseaudio crash after a non-critical recoverable error
  * Fixed: Hotkeys were sometimes not connecting to the correct UI plugins
  * Fixed: Hotkey action "Sort by title" was missing
  * Fixed: Unsupported ID3v2 frames are converted to supported frames instead of discarding
  * Fixed: MP4 crash when encountering unknown metadata fields
  * Fixed: Writing MP4 tags would corrupt the metadata, if the moov box is moving to the end of file
  * Fixed: Off-by-one error when loading unsynchronized ID3v2.3 and 2.2 tags (sktt@github)
  * Fixed: Parsing ALAC M4A files without relying on legacy 24-byte magic cookie
  * Fixed: Saving the player resume state whenever a song finishes playing
  * Fixed: ALSA deadlock / distortion bug caused by changing audio format at a wrong moment
  * Fixed: WMA+CUE crash
  * version 1.8.6
  * Fixed loading encoder presets in non-portable builds
  * Fixed truncation of long group titles in the playlist
  * version 1.8.5
  * Added the new ISO/IEC Base Media File Format library MP4P for working with MP4 files, which removes MP4FF dependency
  * Added support for additional per-track metadata in cuesheets
  * Added updating titlebar when displaying playback position (Nicolai Syvertsen)
  * Added a more convenient way to edit container widgets in design mode (Nicolai Syvertsen)
  * Fixed ALAC bug whiuch caused division by zero exception
  * Fixed cuesheet parser bug caused by unknown/unsupported field names
  * Fixed a series of bugs in the Adplug plugin
  * Fixed a bug when parsing MP3 Xing/Info header, reading incorrect packet count
  * Fixed a number of bugs in artwork plugin, especially affecting the Windows version (Jakub Wasylków, Keith Cancel)
  * Fixed a SHIFT-JIS detection bug which caused memory corruption
  * Fixed a bug when configuring keyboard shortcut involving Shift key
  * Fixed a bug with playlist becoming to small in certain UI layouts
  * Fixed a crash when deadbeef window becomes too small when using certain UI layouts
  * Fixed drawing playlist column separators in certain newer GTK themes
  * Fixed on-screen notification bug when too many notifications accumulated at the same time, spawning too many threads
  * Fixed a bug, causing the Band field to be missing from %%artist%% specifier when using title formatting
  * Fixed bugs leaking file handles in AAC and ALAC plugins (Thomas Jepp)
  * Fixed handling certain non-conformant S3M files
  * Fixed a bug where resizing the log window caused the auto-scroll to stop working (Nicolai Syvertsen)
  * Fixed album shuffle bug, causing the same album to repeat after the last track of the album has finished
  * Fixed shuffle bug causing short tracks to repeat
- Package changes
  * Switch the build to Clang (the only upstream supported compiler since version 1.8.6)
  * Remove deadbeef_disable_psf.patch, use configure switch instead.
  * Use _service generated tarball instead of the broken Github one (missing gitmodules).
  * Spec-cleaner run
* Sat Jul  4 2020 Hillwood Yang <hillwood@opensuse.org>
- Fix deadbeef.appdata.xml
* Thu Jul  2 2020 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.8.4
  * Soundtouch plugin has been updated, and is now included in the releases
  * Added %%last_modified%% title formatting keyword (Cristian Ciocaltea)
  * Fixed stack overflow bug in converter
  * Fixed buffer overflow bug in mp3 parser
  * Fixed handling of leading forward shash character in zipper file names
  * Fixed handling user-specified file mask in artwork plugin
  * Fixed CBR MP3 scanning performance
  * Fixed stack overflow in title formatting tint range calculation
  * Fixed pulseaudio plugin configuration backwards compatibility issue
  * Fixed last.fm scrobbling of streaming shoutcast tracks
  * Fixed deadlock when loading cuesheets which recursively reference themselves
  * Fixed a false-positive when detecting free format MP3 files
  * Fixed skipping unsupported fields in cuesheets
  * Fixed a regression which caused MP3 tag editing to crash when text can't be
    represented as CP1252
  * Fixed playback of certain network streams
  * Fixed handling of ID3v2 COMM frame content description data
- Drop deadbeef-better-ogg-and-aac-converter-support.patch, merged by upstream
- Drop 0003-Fix-operator-precedence-and-uninitialized-value-warn.patch, merged
  by upstream
- Drop deadbeef-fix-return-type.patch, fixed by upstream.
- Drop deadbeef-compiler-warnings.patch, fixed by upstream.
* Thu Apr  2 2020 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.8.3
  * Fixed a CD Text reading issue
  * Added title formatting functions: len2, longer, longest, padcut,
    padcut_right, progress, progress2, right, roman, rot13, shortest, strchr,
    stricmp, strrchr, strstr, substr, tab, trim (esainane@github)
  * Fixed a bunch of memory bugs in title formatting (esainane@github)
  * Added optional automatic playlist sorting (kpcee@github)
  * Added title formatting value %%playback_time_ms%% (nonoo@github)
  * Added an option to start deadbeef hidden / minimized to tray (kpcee@github)
  * Fixed %%_path_raw%% to always produce an URI (Evgeny Kravchenko)
  * Fixed rounding of %%selection_playback_time%% (kpcee@github)
  * Fixed a memory leak in AAC plugin
  * Fixed crash when removing playlist from UI layout (Nicolai Syvertsen)
  * Added logging of plugin load errors
  * Added an option to replaygain scan all unscanned files in playlist
    (kpcee@github)
  * Added detecting and ignoring freeformat MP3 files
  * Removed logging of playlist load debug messages
  * Fixed playback stuttering after deleting files
  * Fixed deleting files using playlist tab context menu
  * Fixed saving playlist after deleting files
  * Fixed saving playlist after replaygain scan
  * Fixed a bunch of crashes and memory leaks when opening playlist context menu
    (Christian Boxdörfer)
  * Fixed a performance issue when seeking in MP3 files
  * Fixed a bunch of issues with Repeat and Shuffle implementation
  * Fixed handling of in-stream HTTP headers for streaming audio
  * Fixed a bunch of bugs in HTTP stream interruption
  * Fixed semicolon-separated values handling in track properties dialog
  * Fixed choosing next track when the currently playing track was removed
  * Fixed seeking out of bounds using hotkeys
  * Fixed saving opus header gain when no replaygain info is present
  * Improved remove from disk dialog (kpcee@github)
  * Fixed ID3v2 TLAN (LANGUAGE) and TMED (MEDIA TYPE) mapping to be consistent
    with other formats
  * Fixed replaygain bug causing it to be ON by default
  * Fixed bug in elapsed time calculation in replaygain scanner UI
  * Fixed a stack overflow bug when writing ID3v1
  * Added ID3v2 POPM rating support, both reading and writing
  * Fixed an issue with splitters not reaching the view edges
  * Fixed single-quote escaping issue in ShellExec
  * Fixed Add Location dialog not adding URLs
  * Fixed ffmpeg file handle leak
  * Added remove playlist confirmation dialog in GTK UI (kpcee@github)
  * Fixed DTS channel count metadata
  * Fixed loading MP3 album art of APIC type=0 (Other)
  * Added album art fallback to png (jakesfr@github)
  * Fixed ALSA hanging after audio format change
  * Fixed handling "ICY 200 OK" status in vfs-curl (thesame)
  * Improved EQ UI layout in the DSP settings
  * Fixed streamer being stuck in buffering mode when trying to play deleted files
- Drop deadbeef-fix_ubuntu_unity_desktop.patch, merged by upstream.
* Sun Feb 16 2020 Hillwood Yang <hillwood@opensuse.org>
- More profiles for ogg and aac
  add deadbeef-better-ogg-and-aac-converter-support.patch
* Thu Jan 16 2020 olaf@aepfle.de
- Fix potential buffer overflow in on_group_by_custom_activate
* Mon Jan  6 2020 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.8.2
  * Volume control from command line supports increment syntax (by
    eauno1re@github)
  * Fixed writing multi-value fields into FLAC tags
  * Map ALBUMARTIST field to ALBUM ARTIST field in FLAC
  * Fixed sound output plugin selection bug in GTK UI
  * Fixed crash when opening files of 0 size
  * Fixed UI freeze when nullout plugin is selected
  * Fixed a regression in restoring the last selected folder in GTK file chooser
- Fixed reture type, add deadbeef-fix-return-type.patch
- Install documents by rpmbuild, add deadbeef-drop-documents-installation.patch
* Sat Jun 29 2019 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.8.1:
  * Fix audio freeze while sorting.
  * Fix a crash when resuming playback of a file that has been
    deleted.
  * Fix error messages when loading PLS playlist with relative
    paths.
  * Fix adjusting shuffle queue after a user initiated track change.
  * Write Album Artist field into OGG files as "ALBUMARTIST".
  * Load external album covers before embedded.
  * Remove the unmaintained sndio plugin.
  * Fix localisation of status bar.
  * Add experimental subgrouping support in playlist, via using a
    "|||" separator for each subsequent nested group, when using
    Group by -> Custom.
  * Add new title formatting functions "$stripprefix" and
    "$swapprefix".
  * Change supereq DSP configuration to be more compact
    horizontally and to have more slider precision.
  * Update Repeat and Shuffle hotkey names to match the menus.
  * Fix rounding bug of total playtime in statusbar.
  * Fix design mode splitter handles dragging beyond the window edges.
  * Fix setting album art size based on larger dimension (by ToadKing).
  * Fix a regression causing custom layouts with splitters look
    wrong.
  * Add a FLAC plugin option to ignore corrupted stream errors.
  * Fix a supereq reentrancy bug, potentially causing crash after
    changing audio output configuration.
  * Fix reloading replaygain info.
  * Fix writing replaygain info to APEv2 tags.
- Rebase deadbeef-compiler-warnings.patch,
  deadbeef_disable_psf.patch.
* Fri May 24 2019 Luigi Baldoni <aloisio@gmx.com>
- Added _service file to remove the non-distributable plugins/psf
  and other undesired files
- Added deadbeef_disable_psf.patch
* Mon Apr  8 2019 olaf@aepfle.de
- Fix filelist for restricted build
* Sun Apr  7 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.8.0
  * added Opus support
  * added ReplayGain Scanner
  * added proper tracks+cue support (in cooperation with wdlkmpx)
  * added/improved MP4 tag reading and writing
  * added loading embedded album art from MP4 files
  * added File Copy and File Move converter presets
  * added Log Window displaying error information from various
    sources (in cooperation with Saivert)
  * improved replaygain configuration and runtime behavior
  * fixed replaygain support in Converter
  * improved reading, storing and editing multi-value tag fields
  * added GBS support to Game_Music_Emu (kode54)
  * added SGC support to Game_Music_Emu
  * fixed clipping prevention for mp3, replaygain is applied
    before clipping
  * fixed vfz_zip handling of colons in filenames
  * fixed wma decoding precision error
  * fixed issues with playing very short files
  * fixed a number of known issues in the Converter
  * UI splitter proportional resizing (cboxdoerfer)
  * added to title formatting: $num, %%_path_raw%%,
    %%_playlist_name%%, $replace, $upper, $lower,
    %%playback_bitrate%%, $repeat, $insert, $len, <<<>>>, >>><<<,
    $pad, $pad_right (saivert)
  * added support for dim and bright text in playlist columns
    (saivert)
  * improved detecting GTK theme colors for custom widgets
  * added new multiline tag editing dialog for individual values
  * added Copy&Paste in playlist (cboxdoerfer)
  * added localization support for plugin UI
  * added Drag'n'drop support from deadbeef to other
    applications (cboxdoerfer)
  * fixed a number of ogg file tagging issues (kode54)
  * fixed multiple crash bugs in AdPlug plugin
  * added UMX module support, ported from foo_dumb
  * updated Game_Music_Emu and VGMplay (kode54)
  * added an option to Converter, to copy the files if the
    format doesn't change
  * added a configuration option `gtkui.start_hidden`, to start
    the player with hidden main window (Radics Péter)
  * added a converter option to retag the files after copying
  * added a context menu action for duplicating playlists (Alex
    Couture-Beil)
  * fixed a number of fadeout issues in Game_Music_Emu
  * fixed musepack seeking issue
  * fixed loading album covers from ID3v2.2
  * fixed mp3 bitrate calculation bug for incomplete files with
    LAME header
  * improved large file support with many internal values
    converted to use 64 bits for sample counts
  * use title formatting for displaying status bar text
  * added %%seltime%% title formatting value, for displaying
    playback time of selected tracks (Thomas Ross)
  * added reading SONGWRITER field from cue sheets (wdlkmpx)
  * added playlist group spacing configuration (saivert)
  * improved mp3 USLT lyrics support (in copperation with Ignat
    Loskutov)
  * improved playlist browser configurability (Jakub Wasylków)
  * added hotkey action for opening track properties (Jakub
    Wasylków)
  * added hotkey actions for add/remove/toggle in playqueue
    (Jakub Wasylków)
  * added --volume command line option (Saivert)
  * improved ISRC and subindex handling in CUE (wdlkmpx)
  * added hotkey actions to move selected tracks up/down (Jakub
    Wasylków)
  * fixed memory access bugs in config handling and supereq
    (github/tsowa)
  * added charset detection based on the whole ID3v2 tag content
  * added automatic charset detection for cdtext (Jakub Wasylków)
  * added configuration for output samplerate setting
  * removed fast scanning mp3 option, since it was too inaccurate
  * improved detection of PSF files, to disambiguate them
    against other files which use the same extension
  * added Edit In Place and Crop options to the track properties
    menu
  * fixed WildMidi playback of some MID files playing more than
    1024 simultaneous notes
  * fixed playing stereo APE files with single-channel silence
  * added wavpack version 5 support with DSD
  * fixed performance issue when reading AdPlug's HSC files
  * fixed loading audio files from GVFS volumes
  * fixed handling of cuesheets in zip files
  * fixed writing tags into tiny ogg files
  * fixed handling FLAC files with huge block sizes over 100KB
  * replaced mp3 parsing code with the new library, which is
    more reliable and tested, and can handle even more obscure
    mp3 files
  * renamed Looping and Order menus to Repeat and Shuffle,
    respectively
  * fixed loading larger Songlenths.txt in sid plugin, and added
    support for Songlengths.md5
- Refreshed deadbeef-fix_ubuntu_unity_desktop.patch and
  deadbeef-compiler-warnings.patch
- Dropped 0001-Explicitly-specify-signedness-for-char.patch and
  0002-Use-signed-values-instead-of-potentially-unsigned-li.patch
  (no longer necessary)
- Enabled opus
* Wed Feb 14 2018 crrodriguez@opensuse.org
- Add missing direct buildRequires
- Remove buildrequires on xorg-x11-libs metapackage
* Fri Nov  3 2017 sor.alexei@meowr.ru
- Add deadbeef.appdata.xml as a separate file and remove
  deadbeef-add-appdata.patch (boo#1066408): the patch was rejected
  upstream. Remove intltool stubs, which fixes the bug.
* Thu Nov  2 2017 stefan.bruens@rwth-aachen.de
  Fix build on ARM/PPC:
  * Add 0001-Explicitly-specify-signedness-for-char.patch
  * Add 0002-Use-signed-values-instead-of-potentially-unsigned-li.patch
  * Add 0003-Fix-operator-precedence-and-uninitialized-value-warn.patch
* Fri Aug 25 2017 olaf@aepfle.de
- Remove mpg123/mad conditional because it is always present
* Fri Jun 30 2017 olaf@aepfle.de
- Better conditional for mp3.so
* Tue Jun 27 2017 olaf@aepfle.de
- buildconditional for mad and mpg123
* Thu May 11 2017 sor.alexei@meowr.ru
- Enable building with libmpg123 and libmad for newer openSUSE
  releases even outside of Packman.
* Wed Mar 15 2017 olaf@aepfle.de
- List all %%doc files to fix build with rpm 4.13
* Sun Feb  5 2017 mailaender@opensuse.org
- Add deadbeef-add-appdata.patch for
  https://software.opensuse.org/appstore
* Sun Feb  5 2017 jengelh@inai.de
- Update description
* Wed May  4 2016 sor.alexei@meowr.ru
- Update to version 0.7.2:
  * Fix title formatting %%filename%% crash.
  * Fix streaming of aac content in mp4 container.
  * Add https:// support to vfs_curl.
  * Add zh_TW translation to deadbeef.desktop.
  * Fix loading cue sheets without any metadata fields.
  * Fix file close bug in VTX plugin.
  * Fix evaluating nested square brackets syntax in title
    formatting.
  * Improve support for large fields in ID3v2 tags.
  * Fix potential crash bug in artwork plugin.
  * Fix path separator '/' escaping regression in converter.
  * Move ffmpeg plugin to the end of plugin list, to prevent
    conflicts with other input plugins.
  * Add $fix_eol, $hex title formatting.
  * Fix importing [, ] and \n characters from old configuration
    files.
  * Fix "Group by artist/date/title" title formatting.
  * Add enumerating/exposing of all supported file extensions to
    ffmpeg plugin.
  * Fix handling of ':' in file path in vfs_zip plugin.
  * Fix old ffmpeg versions support.
  * Fix wma decoder loudness issue.
  * Fix DCA buffer allocation, to make it more musl-friendly.
  * Add $num implementation to title formatting.
  * Fix --nowplaying-tf behavior when player is stopped.
- Remove deadbeef-0.7.1-fix-osd-notify.patch.
- Rebase deadbeef-fix_ubuntu_unity_desktop.patch.
* Wed Apr  6 2016 sor.alexei@meowr.ru
- Add deadbeef-0.7.1-fix-osd-notify.patch from the upstream commit
  da89020: fix a crash when processing "%%filename%%".
* Tue Mar 15 2016 sor.alexei@meowr.ru
- Update to 0.7.1:
  * Fix GTKUI maximised window layout saving/restoring.
  * Fix GTKUI maximised window column autoresize saving/restoring.
  * Fix artwork plugin version checks.
  * Disable bogus shift-jis detection, which was overriding cp1252.
  * Fix MP3 bitrate calculation regression.
  * Fix wrong padding of formatted time.
  * Fix importing legacy title formatting fields bug.
  * Fix incorrect output format after resuming paused session.
  * Fix $ext title formatting bug.
  * Fix %%tracknumber%% title formatting bug.
  * Fix auto-updating title formatting fields.
  * Fix cache cleaner crash bug.
  * Fix crash when trying to play GYM files.
  * Fix importing legacy playlist grouping config.
  * Fix FLAC metadata field mapping.
  * Fix FLAC metadata track/total and disc/total splitting.
* Mon Feb  1 2016 sor.alexei@meowr.ru
- Update to 0.7.0:
  * converter: Fix bug overwriting the source file with destination.
  * artwork: add cache cleaner, MusicBrainz backend;
    + configurable default picture, numerous bugfixes;
    + performance improvements, more customisation options.
  * playlist browser: improve drag-n-drop;
    + double-click / middle-click on empty area to create new
    playlist;
    + middle-click on playlist to remove it;
    + highlight current playlist, configurable columns;
    + sort columns by clicking their headers;
    + performance optimisations.
  * Various selection properties improvements.
  * Add "Skip to ..." next/prev album/genre/composer actions.
  * More appearance customisation options in GTK+UI.
  * Add center-alignment option to playlist columns.
  * Add 1 and 5 second "Seek forward/backward" actions.
  * Fix random gtkui crash when closing playlist via menu.
  * New title formatting implementation, aiming to be compatible
    with fb2k, replacing the old one.
  * Add grouping to search window.
  * Improve error handling in vfs_curl.
  * Fix volume control via mouse scroll when using Gtk3.
  * Fix unwanted restarting when unpausing streaming tracks of
    known length.
  * sid: Use stereo by default, with an option to force mono;
    fix performance issues.
  * cdda: Improve cddb support, libcdparanoia, multiple CD drives,
    speed selection.
  * gtkui: Add selection focus, such that the found tracks will be
    focused while using the search window.
  * tags: Use cp1252 instead of iso8859-1 everywhere.
  * Fix resuming network streams after losing network connection.
  * Fix cuesheet charset detection crash bug.
  * Rename mpgmad plugin to "mp3".
  * Add libmpg123 support as a 2nd backend to mp3 plugin, as default.
  * mp3: Fix xing header parsing, length calculation issues.
  * Favour album artist over artist in "stop after current album"
    mode.
  * gme: Fix SAP file duration and improved looping handling.
  * sid: Automatic detection of HVSC SongLengths.txt from sid file
    paths.
  * gtkui: Add Tabs widget in Design mode.
  * Add sc68 plugin for playing Atari ST music.
  * Add on-demand initialisation to wild-midi, to speed up player
    init.
  * flac: Fix legacy cuesheet handling.
  * Add writing updated replaygain info to all supported tag
    formats.
  * Fix setting focus on the main window / playlist on startup.
  * Change volume up/down actions to have a step of 1dB instead of
    2dB.
  * Fix bigendian support in the converter.
  * Update DUMB and GME to the newest versions.
  * Fix handling of several formats in sndfile plugin.
  * Add support for ORIGINAL_RELEASE_TIME and ORIGINAL_RELEASE_YEAR
    metadata fields.
  * Add loading plugins from a $DEADBEEF_PLUGIN_DIR directory.
  * Fix a bug which was skipping next track after deleting current
    track.
  * DUMB and GME can now do their own proper infinite looping in
    "Loop single" mode.
  * alac: Fix bits per sample varying from what the MP4 container
    specifies.
  * psf: Fix crash after format probing failure.
  * Search window title will show the number of search results.
  * SRC resampler: Fix very rare buffer overflow crash.
  * mp3: Add LAME preset support.
  * album art: Fix scaling of non-square images.
  * ffmpeg: Update to support new library versions.
  * gtkui: Improve playlist column drag-n-drop.
  * Configuration file is now written with 0600 permissions.
  * Add tracktotal and disctotal support for many tagging formats.
  * Add extended ID3v1 genres.
  * Fix int-float conversion off-by-one precision bug.
  * Fix sorting algorithm u8_strcasecmp stability issue.
  * Fix playlist context menu actions to work on clicked playlist,
    instead of the current one.
- Add plugin licences to the main package.
- Move GME plugin to the main package.
- Rebase deadbeef-fix_ubuntu_unity_desktop.patch.
- Update deadbeef-compiler-warnings.patch.
- Remove workaround_div_by_zero.diff: merged upstream.
* Tue Sep  1 2015 sor.alexei@meowr.ru
- Enable Gtk2 build.
- Move Game Music Emu and AOSDK plugins to deadbeef-plugins-extra
  package: non-commercial restriction makes these plugins non-FOSS.
- Require deadbeef-plugins-extra instead of recommending in PMBS.
* Thu Jun 25 2015 olaf@aepfle.de
- Fix compiler warnings
* Tue Jun  2 2015 sor.alexei@meowr.ru
- Fix build of vfs_zip plugin.
- Rename deadbeef-restricted-plugins to deadbeef-plugins-extra.
- Move locales to deadbeef-lang package.
- Move documentation to a proper directory.
- Do not use _service for downloading the tarball.
- Spec cleanup.
* Sat Nov  8 2014 aloisio@gmx.com
- New upstream version 0.6.2
  - added "Stop playback after current album finished" (Aleksejs Popovs)
  - added ALAC, OPUS, OggFlac encoder presets (Ian Nartowicz)
  - added configure option to build artwork plugin without network support
  - added new widget for muting chiptune voices
  - added support for SHIFT-JIS charset detection/recoding (off by default)
  - fixed "stop after current" bug, which required player restart on every change
  - fixed --gui command line option
  - fixed GUI seeking accuracy bug
  - fixed bug in extended frame flags conversion between ID3v2.3 and ID3v2.4 tag formats
  - fixed crash when loading playlist from command line
  - fixed loading album art (APIC frame) from ID3v2.4 with data length indicator
  - fixed non-utf8 locale support in console
  - fixed support for vorbis files with more than 6 channels
  - fixed playlist count limit bug
  - fixed preserving file permissions after editing ogg files
  - fixed several bugs in PLS playlist format support
  - improved FreeBSD and OSX support
  - improved charset detection in CUE and ID3v1
  - improved album art column rendering/resizing (Christian Boxdörfer)
  - improved the build system and the output build quality
  - improved detection of config changes, to avoid unnecessary config writing
  - improved support for reading APEv2 and ID3v1 tags from large files (>2Gb)
  - updated licensing information in all plugins, to include information about all used libraries
  - aac: added workaround for 7 channel sound playback bug
  - ape: play files with format >= 4.11, improved error handling
  - artwork: many fixes and improvements, including support for non-tagged files
  - dumb: added option to configure internal volume
  - ffmpeg: fixed bitrate calculation
  - ffmpeg: fixed replaygain support
  - flac: fixed/improved many things in tag reading and writing code
  - gme: added support for loading gzipped modules from supported archives (e.g. from zips)
  - gtkui, pltbrowser: better accessibility
  - gtkui: added option to disable seekbar overlay
  - gtkui: added option to display playback state as unicode characters, instead of bitmaps
    (works better on HDPI screens)
  - gtkui: added support for design mode to more widgets (seekbak, volumebar, playback toolbar)
  - gtkui: fixed bug in gtk_drag_check_threshold handler
  - gtkui: numerous fixes in widget layout code
  - gtkui: single/double clicking on album art column will select/play the album/group
    (Christian Boxdörfer)
  - lastfm: added support for scrobbling radio streams (off by default)
  - lastfm: added support for scrobbling tracks shorter than 30 sec (off by default)
  - lastfm: improved support for musicbrainz track id
  - mms: fixed few buffer overflow bugs, improved responsiveness
  - mp3: optimized scanner: less backward seeks during frame syncing
  - shellexec: fixed escaping of single quotes, prevent opening copies of shxui dialogs
  - vfs_zip: huge speed improvements
  - vorbis, oggflac: new tagging code (Ian Nartowicz)
  - improved plugin duplicate checking
  - fixed RIFF WAVE header writing in converter
  - fixed 8bit png crash in album art plugin (Ian Nartowicz)
  - static builds now use -O3 -D_FORTIFY_SOURCE=0 compiler flags
  - fixed few issues with implementation of the Play button
  - improved tag writing in converter
  - fixed issues with "background jobs are running" warning
  - changed all wiki links to point to the new wiki on github
  - improved streamer event handling, to make the GUI more responsive and stable
  - fixed cleaning up downloaded temporary playlist files
  - Fixed skipping bad FLAC__METADATA_TYPE_CUESHEET blocks in FLAC
  - added support for uppercase .CUE extension
  - added "mpga" extension support (mp3)
  - fixed seeking backwards using hotkeys when in the beginning of a track
* Mon Mar  3 2014 dap.darkness@gmail.com
- libffmpeg_oldabi-devel (required to build) was replaced by
  libffmpeg-devel to fix packman's build.
* Sat Feb 22 2014 dap.darkness@gmail.com
- new upsream version 0.6.1
  - don't allow spawning multiple instances of converter
  - added config option to help debug buffering/streaming
  - ffmpeg plugin can now handle dynamic data format changes
  - added support for loading plugins from ~/.local/lib{32|64}/
    /deadbeef, depending on running deadbeef build version
  - removed libstdc++ hacks from C++ plugins
  - paused network streams don't attempt to prebuffer until played
  - unpausing network streams always restarts them
  - prevent loading playlists from archives
    (treat them like folders)
  - hide the "Hotkeys" tab from preferences
    if hotkeys plugin is not available
  - don't build shellexecui if not building shellexec
  - prevent passing non-utf8 filenames to progress dialog
  - don't delete replaygain info from FLACs when writing tags
  - gui layout designer, with a set of widgets to choose from
    (View -> Design mode, then use right click)
  - new API for creating GUI extension plugins
  - visualization support, spectrum analyzer and scope widgets
  - new hotkeys system, which adds local hotkeys,
    and many more actions to choose from
  - playlist browser widget:
    a vertical alternative to playlist tabs
  - album art viewer widget
  - selection properties widget
  - button widget: put custom buttons to main window,
    and assign any actions to them
  - showing seek time in the bar during seeking
  - added worldofspectrum downloader to artwork plugin
    (for AY tunes)
  - native flac cuesheet support
  - added GTK3.6 filechooser filter regression workaround
  - added location field to the metadata tab in track properties
  - new WMA plugin
  - added customizable content-type mapper,
    to associate network streams with plugins
  - subtracks no longer get written to pls and m3u
  - warn a user if he attempts to quit while a job is running
    (e.g. converter)
  - added GTK3 touchpad smooth scrolling support
    (kudos to thesame)
  - added option to always convert 16 bit input signal to 24 bit
  - added OPUS and TAK support in the static build (via ffmpeg)
- switched to _service file.
- post-build-checks were disabled because of
  http://code.google.com/p/ddb/issues/detail?id=1057
- update deadbeef-fix_ubuntu_unity_desktop.patch
* Wed Dec 19 2012 andrea@opensuse.org
- new upsream version 0.5.6
  - wavpack: fixed reload_metadata not clearing old data
  - sndfile: fixed big/little endian byte swap buffer overrun
  - gme: fixed loopcount bugs
  - alsa: fixed race condition bug leading to freezes
  - alac: added new ALAC plugin with proper gapless playback support and other goods
  - aac: lots of bugfixes and improvements, as usual, including half/double
    duration bugfix, and custom metadata fields support, and audiobook chapters
  - cue and m3u parsers can now skip utf8 BOM
  - automatically fill new/edited column title from the selected column type
  - removed the frame widget around playlist to make scroll bar more accessible
    in maximized windows
  - restored old GDK drawing in GTK2 plugin, because cairo produces weird results on
    older GTK2 versions -- that means, tabs and playlist now look correct again
    with gtk2.20 and below
  - gtk3 compiling is now enabled by default, if gtk3 sdk is installed
  - --enable/disable-gtkui configure option is removed, now there are only --enable/disable-gtk2
    and --enable/disable-gtk3
  - added Menu key support
  - always auto-name playlist by folder name when empty, even if the playlist title is non-default
  - insert/delete key support in track properties (Ruslan Khusnullin)
  - fixed Enter and Esc keys in track properties
  - fixed playlist column auto-resizing in maximized window
  - added user-agent configuration for last.fm, vfs_curl, etc
  - added cp936 charset detection support. it breaks cp1251 detection, so it's done as an option
  - - look in the preferences (Joey Zheng)
  - show blank instead of "?" when a metadata field is absent
  - fixed local album cover files search order, it's alphabetical now
  - alsa: added a hack/work-around to prevent releasing sound device when a user switches between tracks
  - m3u: improved handling of relative file pathes
  - converter: fixed handling "/" in filenames; fixed tag-writing to files which have special characters
  - fixed resuming last session in shuffle albums mode
  - fixed several libmms freeze/hang/crash bugs
  - vorbis: update waveformat dynamically, so now it's possible to listen the radios which
    switch between mono and stereo dynamically
  - mp3: fixed samplerate shown in the track properties
  - added work-around for unsupported channel masks to wavpack and sndfile plugins
  - fixed notification cover-art loading for tracks with empty album
* Wed Sep 26 2012 jzheng@suse.com
- update to git commit 8f3b1661fd1372508b35de39ca1cc405f1111c0e
- remove patch files as upstream accepts them
- update deadbeef-fix_ubuntu_unity_desktop.patch
- update spec to include alac
* Sat Sep  8 2012 jzheng@suse.com
- update deadbeef_Fix_CDTEXT.patch to prepare for upstream
* Thu Aug 30 2012 jzheng@suse.com
- update to 0.5.5
- remove deadbeef-0.5.0-fix-return-values.patch and
  deadbeef-0.5.0-fix-strcmp.patch as no need any more.
- refresh deadbeef_FixGB.patch and fix_ubuntu_unity_desktop.patch
  based on now version.
- add deadbeef_gtk_combo_box_entry_new_text.patch
- add deadbeef_Fix_CDTEXT.patch
- add enable-gtk3 option to enable gtk3 interface for openSUSE 12.x
- add new plugin files to file list
* Mon Jan 30 2012 jzheng@suse.com
- let version higher than the one in pacman to avoid some update
  issues.
* Sun Jan 29 2012 i@marguerite.su
- Fix Ubuntu Unity Oriented Desktopfile Warnings. SuSE doesn't need that.
* Sun Jan 29 2012 jzheng@suse.com
- Add hack to support cp936 (GBK, GB18030)
* Sat Jun  4 2011 andrea@opensuse.org
- New upstream version 0.5.1
* Mon May 16 2011 andrea@opensuse.org
- New upstream version 0.5.0
* Mon Mar 14 2011 gber@opensuse.org
- call %%desktop_database_post/un and %%icon_theme_cache_post/un
* Thu Dec  2 2010 gber@opensuse.org
- added deadbeef-0.4.4-fix-undefined-assignments.patch and
  deadbeef-0.4.4-fix-return-value.patch to fix compile warnings
* Wed Dec  1 2010 andrea@opensuse.org
- new upstream version 0.4.4
  - fixed crash in OSS plugin
  - fixed random crashes caused by upgrading to libcurl-7.21.2
  - fixed metadata editing in non-english locales
  - fixed switching playlists using hotkeys with caps/num/xcb
  modifiers
  - made preferences window tabs scrollable
  - fixed dts plugin description
  - fixed 'n' hotkey with numlock
  - improved support for icy (shoutcast) protocol
  - fixed ctrl+j (jump to current track) to work correctly with
  multiple playlists
  - fixed cursor/scroll follows playback to work correctly with
  multiple playlists
  - session resume does not seek anymore after skipping failed track
  - fixed seekbar flickering
  - bundled libmms library to fix freezes after updating to 0.6
  - blank cue tracks (without titles) are not skipped anymore
  - fixed trailing whitespace handling in cuesheets
  - "middle mouse button to delete playlist" is now default behavior
  - fixed few issues with auto-saving playlist configuration
  - fixed playlist redraw after cddb queries
* Fri Jun  4 2010 andrea@opensuse.org
- new upstream version 0.4.1 - bug fix release
* Mon May 24 2010 andrea@opensuse.org
- added deadbeef-0.4.0-fix-critical-warning.patch to make
  brp-checks happy
* Sun May 23 2010 andrea@opensuse.org
- New package
